.. highlight:: shell

Installation
============

stable release
--------------

To install TrelloZilla, run this command in your terminal:

.. code-block:: console

    $ pip install trellozilla

This is the preferred method to install TrelloZilla, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/

from sources
------------

The sources for TrelloZilla can be downloaded from our `git repo`_:

.. code-block:: console

    $ git clone git://github.com/moisesguimaraes/trellozilla

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install

.. _git repo: https://github.com/moisesguimaraes/trellozilla
